@@ -13,6 +13,7 @@ ytree imports
 # The full license is in the file COPYING.txt, distributed with this software.
 #-----------------------------------------------------------------------------
 
+from ytree.analysis.analysis_pipeline import AnalysisPipeline
 from ytree.data_structures.load import \
     load
 from ytree.data_structures.tree_node_selector import \
@@ -21,4 +22,9 @@ from ytree.data_structures.tree_node_selector import \
 from ytree.visualization.tree_plot import \
     TreePlot
 
-__version__ = '3.0.0'
+from ytree.utilities.parallel import \
+    parallel_trees, \
+    parallel_tree_nodes, \
+    parallel_nodes
+
+__version__ = '3.1.0'
